@@ -57,13 +57,6 @@ class Client:
             raise RuntimeError('could not resolve universe')
         self.__space = self.__universe['space']
 
-    def load_universe(self, name):
-        universe_id = self.resolve_universe(name)
-        if not universe_id:
-            return None
-        resp = requests.get(f'{self.__app_url}universe/{universe_id}/export?o=1')
-        return load_universe(resp.content)
-
     def resolve(self, identifier):
         if isinstance(identifier, list):
             return [self.resolve(i) for i in identifier]
